==> ausweisapp2_2.0.1.orig.tar.gz: AusweisApp2-2.0.1/src/diagnosis/context/DiagnosisContext.cpp <==
/**
 * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
 */

#include "DiagnosisContext.h"

using namespace governikus;


DiagnosisContext::DiagnosisContext()
	: mPcscVersion()
	, mPcscComponents()
	, mPcscDrivers()
	, mReaderInfos()
	, mReaderInfosNoDriver()
	, mTimestamp()
{
	connect(this, &DiagnosisContext::pcscInfoChanged, this, &DiagnosisContext::modelChanged);
	connect(this, &DiagnosisContext::readerInfosChanged, this, &DiagnosisContext::modelChanged);
	connect(this, &DiagnosisContext::timestampChanged, this, &DiagnosisContext::modelChanged);
}


void DiagnosisContext::setPcscInfo(const QString& pVersion, const QVector<ComponentInfo>& pComponents,
		const QVector<ComponentInfo>& pDrivers)
{
	mPcscVersion = pVersion;
	mPcscComponents = pComponents;
	mPcscDrivers = pDrivers;

	Q_EMIT pcscInfoChanged();
}


void DiagnosisContext::setReaderInfos(const QVector<ReaderInfo>& mInfos)
{
	mReaderInfos = mInfos;

	Q_EMIT readerInfosChanged();
}


void DiagnosisContext::setReaderInfosNoDriver(const QVector<ReaderConfigurationInfo>& pInfos)
{
	mReaderInfosNoDriver = pInfos;

	Q_EMIT readerInfosChanged();
}


void DiagnosisContext::setTimestamp(const QDateTime& pTimestamp)
{
	mTimestamp = pTimestamp;

	Q_EMIT timestampChanged();
}


void DiagnosisContext::setNetworkInterfaces(const QList<QNetworkInterface>& pNetworkInterface)
{
	mNetworkInterfaces = pNetworkInterface;

	Q_EMIT fireNetworkInfoChanged();
}


const QList<QNetworkInterface>& DiagnosisContext::getNetworkInterfaces() const
{
	return mNetworkInterfaces;
}

==> ausweisapp2_2.1.0.orig.tar.gz: AusweisApp-2.1.0/src/diagnosis/context/DiagnosisContext.cpp <==
/**
 * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
 */

#include "DiagnosisContext.h"

using namespace governikus;


DiagnosisContext::DiagnosisContext()
	: mPcscVersion()
	, mPcscComponents()
	, mPcscDrivers()
	, mReaderInfos()
	, mReaderInfosNoDriver()
	, mTimestamp()
{
	connect(this, &DiagnosisContext::pcscInfoChanged, this, &DiagnosisContext::modelChanged);
	connect(this, &DiagnosisContext::readerInfosChanged, this, &DiagnosisContext::modelChanged);
	connect(this, &DiagnosisContext::timestampChanged, this, &DiagnosisContext::modelChanged);
}


void DiagnosisContext::setPcscInfo(const QString& pVersion, const QList<ComponentInfo>& pComponents,
		const QList<ComponentInfo>& pDrivers)
{
	mPcscVersion = pVersion;
	mPcscComponents = pComponents;
	mPcscDrivers = pDrivers;

	Q_EMIT pcscInfoChanged();
}


void DiagnosisContext::setReaderInfos(const QList<ReaderInfo>& mInfos)
{
	mReaderInfos = mInfos;

	Q_EMIT readerInfosChanged();
}


void DiagnosisContext::setReaderInfosNoDriver(const QList<ReaderConfigurationInfo>& pInfos)
{
	mReaderInfosNoDriver = pInfos;

	Q_EMIT readerInfosChanged();
}


void DiagnosisContext::setTimestamp(const QDateTime& pTimestamp)
{
	mTimestamp = pTimestamp;

	Q_EMIT timestampChanged();
}


void DiagnosisContext::setNetworkInterfaces(const QList<QNetworkInterface>& pNetworkInterface)
{
	mNetworkInterfaces = pNetworkInterface;

	Q_EMIT fireNetworkInfoChanged();
}


const QList<QNetworkInterface>& DiagnosisContext::getNetworkInterfaces() const
{
	return mNetworkInterfaces;
}
